@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2015 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -20,6 +18,7 @@ from futurist._futures import Future  # noqa
 from futurist._futures import GreenFuture  # noqa
 
 from futurist._futures import CancelledError  # noqa
+from futurist._futures import TimeoutError  # noqa
 
 from futurist._futures import GreenThreadPoolExecutor  # noqa
 from futurist._futures import ProcessPoolExecutor  # noqa
